==> openflowplugin-extension-nicira-0.7.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/src/choice/grouping/src/choice/SrcNxNshc3CaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.src.choice.grouping.src.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link SrcNxNshc3CaseBuilder} instances.
 *
 * @see SrcNxNshc3CaseBuilder
 *
 */
public class SrcNxNshc3CaseBuilder implements Builder<SrcNxNshc3Case> {

    private Boolean _nxNshc3Dst;


    Map<Class<? extends Augmentation<SrcNxNshc3Case>>, Augmentation<SrcNxNshc3Case>> augmentation = Collections.emptyMap();

    public SrcNxNshc3CaseBuilder() {
    }
    public SrcNxNshc3CaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshc3Grouping arg) {
        this._nxNshc3Dst = arg.isNxNshc3Dst();
    }

    public SrcNxNshc3CaseBuilder(SrcNxNshc3Case base) {
        this._nxNshc3Dst = base.isNxNshc3Dst();
        if (base instanceof SrcNxNshc3CaseImpl) {
            SrcNxNshc3CaseImpl impl = (SrcNxNshc3CaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<SrcNxNshc3Case>>, Augmentation<SrcNxNshc3Case>> aug =((AugmentationHolder<SrcNxNshc3Case>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshc3Grouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshc3Grouping) {
            this._nxNshc3Dst = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshc3Grouping)arg).isNxNshc3Dst();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshc3Grouping]");
    }

    public Boolean isNxNshc3Dst() {
        return _nxNshc3Dst;
    }
    
    @SuppressWarnings("unchecked")
    public <E extends Augmentation<SrcNxNshc3Case>> E augmentation(Class<E> augmentationType) {
        return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public SrcNxNshc3CaseBuilder setNxNshc3Dst(final Boolean value) {
        this._nxNshc3Dst = value;
        return this;
    }
    
    public SrcNxNshc3CaseBuilder addAugmentation(Class<? extends Augmentation<SrcNxNshc3Case>> augmentationType, Augmentation<SrcNxNshc3Case> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public SrcNxNshc3CaseBuilder removeAugmentation(Class<? extends Augmentation<SrcNxNshc3Case>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public SrcNxNshc3Case build() {
        return new SrcNxNshc3CaseImpl(this);
    }

    private static final class SrcNxNshc3CaseImpl implements SrcNxNshc3Case {
    
        private final Boolean _nxNshc3Dst;
    
        private Map<Class<? extends Augmentation<SrcNxNshc3Case>>, Augmentation<SrcNxNshc3Case>> augmentation = Collections.emptyMap();
    
        SrcNxNshc3CaseImpl(SrcNxNshc3CaseBuilder base) {
            this._nxNshc3Dst = base.isNxNshc3Dst();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<SrcNxNshc3Case> getImplementedInterface() {
            return SrcNxNshc3Case.class;
        }
    
        @Override
        public Boolean isNxNshc3Dst() {
            return _nxNshc3Dst;
        }
        
        @SuppressWarnings("unchecked")
        @Override
        public <E extends Augmentation<SrcNxNshc3Case>> E augmentation(Class<E> augmentationType) {
            return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxNshc3Dst);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!SrcNxNshc3Case.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            SrcNxNshc3Case other = (SrcNxNshc3Case)obj;
            if (!Objects.equals(_nxNshc3Dst, other.isNxNshc3Dst())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                SrcNxNshc3CaseImpl otherImpl = (SrcNxNshc3CaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<SrcNxNshc3Case>>, Augmentation<SrcNxNshc3Case>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("SrcNxNshc3Case");
            CodeHelpers.appendValue(helper, "_nxNshc3Dst", _nxNshc3Dst);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.8.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/src/choice/grouping/src/choice/SrcNxNshc3CaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.src.choice.grouping.src.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link SrcNxNshc3CaseBuilder} instances.
 *
 * @see SrcNxNshc3CaseBuilder
 *
 */
public class SrcNxNshc3CaseBuilder implements Builder<SrcNxNshc3Case> {

    private Boolean _nxNshc3Dst;


    Map<Class<? extends Augmentation<SrcNxNshc3Case>>, Augmentation<SrcNxNshc3Case>> augmentation = Collections.emptyMap();

    public SrcNxNshc3CaseBuilder() {
    }
    public SrcNxNshc3CaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshc3Grouping arg) {
        this._nxNshc3Dst = arg.isNxNshc3Dst();
    }

    public SrcNxNshc3CaseBuilder(SrcNxNshc3Case base) {
        this._nxNshc3Dst = base.isNxNshc3Dst();
        if (base instanceof SrcNxNshc3CaseImpl) {
            SrcNxNshc3CaseImpl impl = (SrcNxNshc3CaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<SrcNxNshc3Case>>, Augmentation<SrcNxNshc3Case>> aug =((AugmentationHolder<SrcNxNshc3Case>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshc3Grouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshc3Grouping) {
            this._nxNshc3Dst = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshc3Grouping)arg).isNxNshc3Dst();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshc3Grouping]");
    }

    public Boolean isNxNshc3Dst() {
        return _nxNshc3Dst;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<SrcNxNshc3Case>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public SrcNxNshc3CaseBuilder setNxNshc3Dst(final Boolean value) {
        this._nxNshc3Dst = value;
        return this;
    }
    
    public SrcNxNshc3CaseBuilder addAugmentation(Class<? extends Augmentation<SrcNxNshc3Case>> augmentationType, Augmentation<SrcNxNshc3Case> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public SrcNxNshc3CaseBuilder removeAugmentation(Class<? extends Augmentation<SrcNxNshc3Case>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public SrcNxNshc3Case build() {
        return new SrcNxNshc3CaseImpl(this);
    }

    private static final class SrcNxNshc3CaseImpl implements SrcNxNshc3Case {
    
        private final Boolean _nxNshc3Dst;
    
        private Map<Class<? extends Augmentation<SrcNxNshc3Case>>, Augmentation<SrcNxNshc3Case>> augmentation = Collections.emptyMap();
    
        SrcNxNshc3CaseImpl(SrcNxNshc3CaseBuilder base) {
            this._nxNshc3Dst = base.isNxNshc3Dst();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<SrcNxNshc3Case> getImplementedInterface() {
            return SrcNxNshc3Case.class;
        }
    
        @Override
        public Boolean isNxNshc3Dst() {
            return _nxNshc3Dst;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<SrcNxNshc3Case>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxNshc3Dst);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!SrcNxNshc3Case.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            SrcNxNshc3Case other = (SrcNxNshc3Case)obj;
            if (!Objects.equals(_nxNshc3Dst, other.isNxNshc3Dst())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                SrcNxNshc3CaseImpl otherImpl = (SrcNxNshc3CaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<SrcNxNshc3Case>>, Augmentation<SrcNxNshc3Case>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("SrcNxNshc3Case");
            CodeHelpers.appendValue(helper, "_nxNshc3Dst", _nxNshc3Dst);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}
